use std::path::PathBuf;
use sqlx::sqlite::{
    SqlitePool,
    SqliteConnectOptions,
    SqliteQueryResult,
    SqliteSynchronous,
};

/// Prepare sqlite database connection
pub async fn connect(path: &PathBuf) -> sqlx::Result<SqlitePool> {
    let connect_options = SqliteConnectOptions::new()
        .filename(&path)
        .create_if_missing(true)
        .synchronous(SqliteSynchronous::Normal);
    SqlitePool::connect_with(connect_options).await
}

/// Create tables from template
pub async fn load_template(sqlite_handle: &SqlitePool) -> sqlx::Result<SqliteQueryResult> {
    sqlx::query(concat!(
        include_str!("users.sql"),
        include_str!("security_preferences.sql"),
        include_str!("privacy_preferences.sql"),
        include_str!("notification_preferences.sql"),
        include_str!("external_servers_privacy_preferences.sql"),
        include_str!("external_servers_preferences.sql"),
    )).execute(sqlite_handle).await
}

pub async fn add_test_user(sqlite_handle: &mut SqliteConnection)-> sqlx::Result<SqliteQueryResult>{
    sqlx::query("insert into users values('1923123','Elierik','erikeli',1,2,3);").execute(sqlite_handle).await
}

pub async fn sqlite_out(sqlite_handle: &mut SqliteConnection, query:&str, index:usize) -> Result<String, sqlx::Error> {
    sqlx::query(query).fetch_one(sqlite_handle).await.unwrap().try_get(index)
}

